@@ -13,6 +13,7 @@
 
 import os
 import argparse
+import shutil
 
 from gi.repository import Gio
 from gi.repository import GLib
@@ -22,6 +23,11 @@ from ninix.dll import SAORI
 class Saori(SAORI):
 
     def __init__(self):
+        if 'XDG_DATA_HOME' in os.environ:
+            XDG_DATA_HOME = os.environ['XDG_DATA_HOME']
+        else:
+            XDG_DATA_HOME = os.environ['HOME'] + '/.local/share'
+        self.HOME_TRASH = os.fsencode(os.path.join(XDG_DATA_HOME, 'Trash'))
         SAORI.__init__(self)
 
     def setup(self):
@@ -45,6 +51,19 @@ class Saori(SAORI):
             self.notify = None
             return 0
 
+    def get_volume_trash(self):
+        vm = Gio.VolumeMonitor.get()
+        for m in vm.get_mounts():
+            mp = m.get_default_location().get_path()
+            if mp is None:
+                continue
+            volume_trash = os.path.join(mp, '.Trash', str(os.getuid()))
+            if not os.path.exists(volume_trash):
+                volume_trash = os.path.join(mp, '.Trash-' + str(os.getuid()))
+            if not os.path.exists(volume_trash):
+                continue
+            yield os.fsencode(volume_trash)
+
     def get_dir_size(self, dir_name):
         file_count = 0
         dir_size = 0
@@ -54,13 +73,28 @@ class Saori(SAORI):
                 dir_size += os.path.getsize(os.path.join(path, file))
         return (file_count, dir_size)
 
+    def empty_trash(self, path):
+        for info in os.listdir(os.path.join(path, b'info')):
+            trash = info[0:-len(b'.trashinfo')]
+            filepath = os.path.join(path, b'files', trash)
+            infopath = os.path.join(path, b'info', info)
+            if os.path.isfile(filepath) or os.path.islink(filepath):
+                os.remove(filepath)
+                os.remove(infopath)
+            elif os.path.isdir(filepath):
+                shutil.rmtree(filepath)
+                os.remove(infopath)
+
     def execute(self, argument):
         args = self.parser.parse_args(argument[0].split())
         if self.notify is None:
             return self.RESPONSE[400]
         if args.number_of_items:
-            file_count, dir_size = self.get_dir_size(
-                os.fsencode(os.path.expanduser('~/.local/share/Trash'))) # XXX
+            file_count, dir_size = self.get_dir_size(self.HOME_TRASH)
+            for volume_trash in self.get_volume_trash():
+                count, size = self.get_dir_size(volume_trash)
+                file_count += count
+                dir_size += size
             return b''.join((b'SAORI/1.0 200 OK\r\n',
                              b'Result: ',
                              str(file_count).encode('ascii'),
@@ -69,10 +103,15 @@ class Saori(SAORI):
                              str(dir_size).encode('ascii'),
                              b'\r\n\r\n'))
         elif args.empty:
-            result = self.notify.call_sync(
-                'EmptyTrash', GLib.Variant('()', ()),
-                Gio.DBusCallFlags.NONE, -1, None)
-            return b''.join((b'SAORI/1.0 200 OK\r\n',
-                             b'Result: ',
-                             b'1', # FIXME
-                             b'\r\n\r\n'))
+            if args.force:
+                self.empty_trash(self.HOME_TRASH)
+                for volume_trash in self.get_volume_trash():
+                    self.empty_trash(volume_trash)
+            else:
+                result = self.notify.call_sync(
+                    'EmptyTrash', GLib.Variant('()', ()),
+                    Gio.DBusCallFlags.NONE, -1, None)
+                return b''.join((b'SAORI/1.0 200 OK\r\n',
+                                 b'Result: ',
+                                 b'1', # FIXME
+                                 b'\r\n\r\n'))
