@@ -38,7 +38,6 @@ class Saori(SAORI):
         bus.connect('message', self.on_message)
         self.filepath = None
         self.__sakura = None
-        self.state = 0 # 0/1/2 - stop/playing/paused
 
     def need_ghost_backdoor(self, sakura):
         self.__sakura = sakura
@@ -59,12 +58,10 @@ class Saori(SAORI):
             if argv[0] == 'stop':
                 self.player.set_state(Gst.State.NULL)
             elif argv[0] == 'play':
-                if self.state == 2:
-                    self.state = 1
+                if self.player.get_state(timeout=Gst.SECOND)[1] == Gst.State.PAUSED:
                     self.player.set_state(Gst.State.PLAYING)
                     return self.RESPONSE[204]
-                elif self.state == 1:
-                    self.state = 2
+                elif self.player.get_state(timeout=Gst.SECOND)[1] == Gst.State.PLAYING:
                     self.player.set_state(Gst.State.PAUSED)
                     return self.RESPONSE[204]
                 if self.filepath is not None and os.path.isfile(self.filepath):
@@ -89,9 +86,7 @@ class Saori(SAORI):
         t = message.type
         if t == Gst.MessageType.EOS:
             self.player.set_state(Gst.State.NULL)
-            self.state = 0
         elif t == Gst.MessageType.ERROR:
             self.player.set_state(Gst.State.NULL)
             err, debug = message.parse_error()
             logging.error('Error: {0}, {1}'.format(err, debug))
-            self.state = 0
