@@ -83,56 +83,60 @@ class Saori(SAORI):
                 result = 0
         return result
 
-    def request(self, req): ## FIXME
+    def request(self, req):
         req_type, argument = self.evaluate_request(req)
         if not req_type:
             result = self.RESPONSE[400]
         elif req_type == 'GET Version':
             result = self.RESPONSE[204]
         elif req_type == 'EXECUTE':
-            if not argument:
-                result = self.RESPONSE[400]
-            elif not self.__check_argument(argument):
-                result = self.RESPONSE[400]
-            else:
-                name = argument[0]
-                if name == 'GET_POSITION':
-                    if argument[1] == self.sakura_name: ## FIXME: HWND
-                        side = 0
-                    elif argument[1] == self.kero_name: ## FIXME: HWND
-                        side = 1
-                    else:
-                        return self.RESPONSE[400]
-                    try:
-                        x, y = self.__sakura.get_surface_position(side)
-                        w, h = self.__sakura.get_surface_size(side)
-                        result = 'SAORI/1.0 200 OK\r\n' \
-                            'Result: {0:d}\r\n' \
-                            'Value0: {1:d}\r\n' \
-                            'Value1: {2:d}\r\n' \
-                            'Value2: {3:d}\r\n\r\n'.format(x, x, x + w // 2, x + w)
-                        result = result.encode('ascii')
-                    except:
-                        result = self.RESPONSE[500]
-                elif name == 'GET_DESKTOP_SIZE':
-                    try:
-                        left, top, scrn_w, scrn_h = ninix.pix.get_workarea()
-                        result = 'SAORI/1.0 200 OK\r\n' \
-                            'Result: {0:d}\r\n' \
-                            'Value0: {1:d}\r\n' \
-                            'Value1: {2:d}\r\n\r\n'.format(scrn_w, scrn_w, scrn_h)
-                        result = result.encode('ascii')
-                    except:
-                        result = self.RESPONSE[500]
-                else:
-                    self.enqueue_commands(name, argument[1:])
-                    if self.timeout_id is None:
-                        self.do_idle_tasks()
-                    result = self.RESPONSE[204]
+            result = self.execute(argument)
         else:
             result = self.RESPONSE[400]
         return result
 
+    def execute(self, args):
+        if not args:
+            result = self.RESPONSE[400]
+        elif not self.__check_argument(args):
+            result = self.RESPONSE[400]
+        else:
+            name = args[0]
+            if name == 'GET_POSITION':
+                if args[1] == self.sakura_name: ## FIXME: HWND
+                    side = 0
+                elif args[1] == self.kero_name: ## FIXME: HWND
+                    side = 1
+                else:
+                    return self.RESPONSE[400]
+                try:
+                    x, y = self.__sakura.get_surface_position(side)
+                    w, h = self.__sakura.get_surface_size(side)
+                    result = 'SAORI/1.0 200 OK\r\n' \
+                        'Result: {0:d}\r\n' \
+                        'Value0: {1:d}\r\n' \
+                        'Value1: {2:d}\r\n' \
+                        'Value2: {3:d}\r\n\r\n'.format(x, x, x + w // 2, x + w)
+                    result = result.encode('ascii')
+                except:
+                    result = self.RESPONSE[500]
+            elif name == 'GET_DESKTOP_SIZE':
+                try:
+                    left, top, scrn_w, scrn_h = ninix.pix.get_workarea()
+                    result = 'SAORI/1.0 200 OK\r\n' \
+                        'Result: {0:d}\r\n' \
+                        'Value0: {1:d}\r\n' \
+                        'Value1: {2:d}\r\n\r\n'.format(scrn_w, scrn_w, scrn_h)
+                    result = result.encode('ascii')
+                except:
+                    result = self.RESPONSE[500]
+            else:
+                self.enqueue_commands(name, args[1:])
+                if self.timeout_id is None:
+                    self.do_idle_tasks()
+                result = self.RESPONSE[204]
+        return result
+
     def enqueue_commands(self, command, args):
         #assert command in ['MOVE', 'MOVE_INSIDE', 'MOVETO', 'MOVETO_INSIDE',
         #                   'ZMOVE', 'WAIT', 'NOTIFY',
