@@ -176,22 +176,53 @@ class Menu:
         self.__fontcolor['normal'] = background
         self.__fontcolor['prelight'] = foreground
 
-    def set_pixmap(self, path_background, path_sidebar, path_foreground):
-        if path_background is not None:
+    def set_pixmap(self, path_background, path_sidebar, path_foreground,
+                   align_background, align_sidebar, align_foreground):
+        self.__imagepath['background'] = None
+        self.__imagepath['foreground'] = None
+        self.__imagepath['sidebar'] = None
+        if path_background is not None and os.path.exists(path_background):
+            try:
+                color = ninix.pix.get_png_lastpix(path_background)
+                self.__imagepath['background'] = b''.join(
+                    (b"background-image: url('", path_background, b"');\n",
+                     b"background-color: ", color, b";\n",
+                     b"background-position: ", align_background, b";\n"))
+            except:
+                pass
+        if self.__imagepath['background'] is None:
             self.__imagepath['background'] = b''.join(
-                (b"background-image: url('", path_background, b"');\n"))
-        else:
-            self.__imagepath['background'] = b"background-image: none;\n"
-        if path_foreground is not None:
+                (b"background-image: none;\n",
+                 b"background-color: transparent;\n",
+                 b"background-position: left;\n"))
+        if path_foreground is not None and os.path.exists(path_foreground):
+            try:
+                color = ninix.pix.get_png_lastpix(path_foreground)
+                self.__imagepath['foreground'] = b''.join(
+                    (b"background-image: url('", path_foreground, b"');\n",
+                     b"background-color: ", color, b";\n",
+                     b"background-position: ", align_foreground, b";\n"))
+            except:
+                pass
+        if self.__imagepath['foreground'] is None:
             self.__imagepath['foreground'] = b''.join(
-                (b"background-image: url('", path_foreground, b"');\n"))
-        else:
-            self.__imagepath['foreground'] = b"background-image: none;\n"
-        if path_sidebar is not None:
+                (b"background-image: none;\n",
+                 b"background-color: transparent;\n",
+                 b"background-position: left;\n"))
+        if path_sidebar is not None and os.path.exists(path_sidebar):
+            try:
+                color = ninix.pix.get_png_lastpix(path_sidebar)
+                self.__imagepath['sidebar'] = b''.join(
+                    (b"background-image: url('", path_sidebar, b"');\n",
+                     b"background-color: ", color, b";\n",
+                     b"background-position: ", align_sidebar, b";\n"))
+            except:
+                pass
+        if self.__imagepath['sidebar'] is None:
             self.__imagepath['sidebar'] = b''.join(
-                (b"background-image: url('", path_sidebar, b"');\n"))
-        else:
-            self.__imagepath['sidebar'] = b"background-image: none;\n"
+                (b"background-image: none;\n",
+                 b"background-color: transparent;\n",
+                 b"background-position: top;\n"))
 
     def __set_mayuna_menu(self, side):
         if len(self.__mayuna_menu) > side and \
