@@ -99,6 +99,7 @@ class Sakura:
         self.script_mode = self.BROWSE_MODE
         self.script_post_proc = []
         self.script_finally = []
+        self.script_position = 0
         self.event_queue = []
         self.__current_script = ''
         self.__balloon_life = 0
@@ -445,7 +446,7 @@ class Sakura:
         return self.script_mode == self.PAUSE_MODE
 
     def is_talking(self):
-        return int(self.processed_script or self.processed_text)
+        return int(bool(self.processed_script or self.processed_text))
 
     def busy(self, check_updateman=True):
         return bool(self.time_critical_session or \
@@ -820,6 +821,12 @@ class Sakura:
             if self.sstp_request_handler:
                 self.sstp_request_handler.send_sstp_break()
                 self.sstp_request_handler = None
+            if self.is_talking():
+                self.notify_event('OnBalloonBreak',
+                                  self.__current_script, side,
+                                  self.script_position)
+            else:
+                self.notify_event('OnBalloonClose', self.__current_script)
             self.reset_script(1)
             self.stand_by(0)
 
@@ -918,30 +925,81 @@ class Sakura:
         path_background, path_sidebar, path_foreground, \
             align_background, align_sidebar, align_foreground = \
             self.surface.get_menu_pixmap()
-        top_dir = os.path.join(self.get_prefix(), b'ghost', b'master')
+        top_dir = self.surface.prefix
+        ghost_dir = os.path.join(self.get_prefix(), b'ghost', b'master')
+        name = self.getstring('menu.background.bitmap.filename')
+        if name:
+            name = name.replace('\\', '/')
+            path_background = os.path.join(top_dir, os.fsencode(name))
+        if path_background is None:
+            path_background = os.path.join(ghost_dir,
+                                           os.fsencode('menu_background.png'))
         if not os.path.exists(path_background):
-            path = os.path.join(top_dir, b'menu_background.png')
-            if os.path.exists(path):
-                path_background = path
-            else:
-                path_background = None
+            path_background = None
+        name = self.getstring('menu.sidebar.bitmap.filename')
+        if name:
+            name = name.replace('\\', '/')
+            path_sidebar = os.path.join(top_dir, os.fsencode(name))
+        if path_sidebar is None:
+            path_sidebar = os.path.join(ghost_dir,
+                                        os.fsencode('menu_sidebar.png'))
         if not os.path.exists(path_sidebar):
-            path = os.path.join(top_dir, b'menu_sidebar.png')
-            if os.path.exists(path):
-                path_sidebar = path
-            else:
-                path_sidebar = None
+            path_sidebar = None
+        name = self.getstring('menu.foreground.bitmap.filename')
+        if name:
+            name = name.replace('\\', '/')
+            path_foreground = os.path.join(top_dir, os.fsencode(name))
+        if path_foreground is None:
+            path_foreground = os.path.join(ghost_dir,
+                                           os.fsencode('menu_foreground.png'))
         if not os.path.exists(path_foreground):
-            path = os.path.join(top_dir, b'menu_foreground.png')
-            if os.path.exists(path):
-                path_foreground = path
-            else:
-                path_foreground = None
+            path_foreground = None
+        align = self.getstring('menu.background.alignment')
+        if align:
+            align_background = align
+        if align_background not in ['lefttop', 'righttop', 'centertop']:
+            align_background = 'lefttop'
+        align_background = align_background[:-3].encode('ascii') # XXX
+        align = self.getstring('menu.sidebar.alignment')
+        if align:
+            align_sidebar = align
+        if align_sidebar not in ['top', 'bottom']:
+            align_sidebar = 'top'
+        align_sidebar = align_sidebar.encode('ascii') # XXX
+        align = self.getstring('menu.foreground.alignment')
+        if align:
+            align_foreground = align
+        if align_foreground not in ['lefttop', 'righttop', 'centertop']:
+            align_foreground = 'lefttop'
+        align_foreground = align_foreground[:-3].encode('ascii') # XXX
         return path_background, path_sidebar, path_foreground, \
             align_background, align_sidebar, align_foreground
 
     def get_menu_fontcolor(self):
-        return self.surface.get_menu_fontcolor()
+        background, foreground = self.surface.get_menu_fontcolor()
+        color_r = self.getstring('menu.background.font.color.r')
+        color_g = self.getstring('menu.background.font.color.g')
+        color_b = self.getstring('menu.background.font.color.b')
+        try:
+            color_r = max(0, min(255, int(color_r)))
+            color_g = max(0, min(255, int(color_g)))
+            color_b = max(0, min(255, int(color_b)))
+        except:
+            pass
+        else:
+            background = (color_r, color_g, color_b)
+        color_r = self.getstring('menu.foreground.font.color.r')
+        color_g = self.getstring('menu.foreground.font.color.g')
+        color_b = self.getstring('menu.foreground.font.color.b')
+        try:
+            color_r = max(0, min(255, int(color_r)))
+            color_g = max(0, min(255, int(color_g)))
+            color_b = max(0, min(255, int(color_b)))
+        except:
+            pass
+        else:
+            foreground = (color_r, color_g, color_b)
+        return background, foreground
 
     def get_mayuna_menu(self):
         return self.surface.get_mayuna_menu()
@@ -1251,8 +1309,12 @@ class Sakura:
             pass
         elif idle > self.__balloon_life > 0 and not self.passivemode:
             self.__balloon_life = 0
+            for side in range(self.char):
+                if self.balloon_is_shown(side):
+                    self.notify_event('OnBalloonTimeout',
+                                      self.__current_script)
+                    break
             self.stand_by(0)
-            self.notify_event('OnBalloonClose', self.__current_script)
             if self.request_parent('GET', 'get_preference', 'sink_after_talk'):
                 self.surface.lower_all()
         elif self.event_queue and self.handle_event():
@@ -1373,6 +1435,7 @@ class Sakura:
         if not script.rstrip().endswith(r'\e'):
             script = ''.join((script, r'\e'))
         self.processed_script = []
+        self.script_position = 0
         while 1:
             try:
                 self.processed_script.extend(self.script_parser.parse(script))
@@ -1755,7 +1818,7 @@ class Sakura:
                 self.passivemode = 1
             elif args[0:1] == ['leave']:
                 self.passivemode = 0
-        elif args[0:2] == ['set', 'alignmentondesktop']:
+        elif args[0:2] == ['set', 'alignmentondesktop'] and argc > 2:
             if args[2] == 'bottom':
                 if self.synchronized_session:
                     for chr_id in self.synchronized_session:
@@ -1768,14 +1831,15 @@ class Sakura:
                         self.align_top(chr_id)
                 else:
                     self.align_top(self.script_side)
-        elif args[0:2] == ['set', 'alignmenttodesktop']:
-            if args[2] == 'free':
+            elif args[2] == 'free':
                 if self.synchronized_session:
                     for chr_id in self.synchronized_session:
                         self.surface.set_alignment(chr_id, 2)
                 else:
                     self.surface.set_alignment(self.script_side, 2)
-        elif args[0:2] == ['set', 'windowstate']:
+            elif args[2] == 'default':
+                self.surface.reset_alignment()
+        elif args[0:2] == ['set', 'windowstate'] and argc > 2:
             if args[2] == 'minimize':
                 self.surface.window_iconify(True)
             ##elif args[2] == '!minimize':
@@ -1784,10 +1848,10 @@ class Sakura:
                 self.surface.window_stayontop(True)
             elif args[2] == '!stayontop':
                 self.surface.window_stayontop(False)
-        elif args[0:2] == ['set', 'wallpaper']:
+        elif args[0:2] == ['set', 'wallpaper'] and argc > 2:
             path = os.path.join(self.get_prefix(), os.fsencode(args[2]))
             opt = None
-            if len(args) > 3:
+            if argc > 3:
                 # possible picture_options value:
                 # "none", "wallpaper", "centered", "scaled", "stretched"
                 options = {
@@ -1811,28 +1875,28 @@ class Sakura:
                     gsettings.set_string('picture-options', opt)
                 else:
                     pass # not implemented yet
-        elif args[0:2] == ['set', 'otherghosttalk']:
+        elif args[0:2] == ['set', 'otherghosttalk'] and argc > 2:
             if args[2] == 'true':
                 self.__listening['OnOtherGhostTalk'] = True
             elif args[2] == 'false':
                 self.__listening['OnOtherGhostTalk'] = False
             else:
                 pass ## FIXME
-        elif args[0:2] == ['set', 'othersurfacechange']:
+        elif args[0:2] == ['set', 'othersurfacechange'] and argc > 2:
             if args[2] == 'true':
                 self.__listening['OnOtherSurfaceChange'] = True
             elif args[2] == 'false':
                 self.__listening['OnOtherSurfaceChange'] = False
             else:
                 pass ## FIXME
-        elif args[0] == 'sound':
+        elif args[0:1] == 'sound' and argc > 1:
             command = args[1]
             if self.audio_player is None:
                 return
             if command == 'stop':
                 self.audio_player.set_state(Gst.State.NULL)
                 self.audio_loop = False
-            elif command == 'play':
+            elif command == 'play' and argc > 2:
                 filename = args[2]
                 filename = get_normalized_path(filename)
                 path = os.path.join(self.get_prefix(),
@@ -1843,7 +1907,7 @@ class Sakura:
                         'uri', 'file://' + urllib.parse.quote(path))
                     self.audio_loop = False
                     self.audio_player.set_state(Gst.State.PLAYING)
-            elif command == 'cdplay':
+            elif command == 'cdplay' and argc > 2:
                 self.audio_player.set_state(Gst.State.NULL)
                 try:
                     track = int(args[2])
@@ -1853,7 +1917,7 @@ class Sakura:
                     'uri', 'cdda://{}'.format(track))
                 self.audio_loop = False
                 self.audio_player.set_state(Gst.State.PLAYING)
-            elif command == 'loop':
+            elif command == 'loop' and argc > 2:
                 filename = args[2]
                 filename = get_normalized_path(filename)
                 path = os.path.join(self.get_prefix(),
@@ -1877,9 +1941,9 @@ class Sakura:
                     self.audio_player.set_state(Gst.State.PLAYING)
             else:
                 pass ## FIXME
-        elif args[0] == '*':
+        elif args[0:1] == '*':
             self.balloon.append_sstp_marker(self.script_side)
-        elif args[0] == 'quicksession':
+        elif args[0:1] == 'quicksession' and argc > 1:
             if args[1] == 'true':
                 self.quick_session = 1
             elif args[1] == 'false':
@@ -1980,8 +2044,9 @@ class Sakura:
                 self.script_wait = time.time() + script_speed * 0.02
             return
         node = self.processed_script.pop(0)
+        self.script_position = node[-1]
         if node[0] == ninix.script.SCRIPT_TAG:
-            name, args = node[1], node[2:]
+            name, args = node[1], node[2:-1]
             if name in self.__script_tag:
                 self.__script_tag[name](self, args)
             else:
@@ -2008,6 +2073,7 @@ class Sakura:
             self.__current_script = ''
         self.processed_script = None
         self.processed_text = ''
+        self.script_position = 0
         self.time_critical_session = 0
         self.quick_session = 0
         self.set_synchronized_session(reset=1)
