@@ -162,12 +162,12 @@ class Parser:
                 if string_chunks:
                     text.append((TEXT_STRING, ''.join(string_chunks)))
                 if text:
-                    self.script.append((SCRIPT_TEXT, tuple(text)))
+                    self.script.append((SCRIPT_TEXT, tuple(text), self.column))
                 raise self.perror('unknown tag', skip='length')
             elif token == TOKEN_STRING and lexeme == '%':
                 string_chunks.append(lexeme)
                 text.append((TEXT_STRING, ''.join(string_chunks)))
-                self.script.append((SCRIPT_TEXT, tuple(text)))
+                self.script.append((SCRIPT_TEXT, tuple(text), self.column))
                 raise self.perror('unknown meta string', skip='length')
             if token in [TOKEN_NUMBER, TOKEN_OPENED_SBRA,
                          TOKEN_STRING, TOKEN_CLOSED_SBRA]:
@@ -184,31 +184,32 @@ class Parser:
                     text.append((TEXT_META, lexeme, argument))
                 elif lexeme == '%*':
                     if text:
-                        self.script.append((SCRIPT_TEXT, tuple(text)))
+                        self.script.append((SCRIPT_TEXT, tuple(text),
+                                            self.column))
                         text = []
                     self.script.append((SCRIPT_TAG, '\\!',
-                                        ((TEXT_STRING, '*'),)))
+                                        ((TEXT_STRING, '*'),), self.column))
                 else:
                     text.append((TEXT_META, lexeme))
                 continue
             if text:
-                self.script.append((SCRIPT_TEXT, tuple(text)))
+                self.script.append((SCRIPT_TEXT, tuple(text), self.column))
                 text = []
             if lexeme in ['\\a', '\\c', '\\e', '\\t', '\\_e',
                           '\\v', '\\x', '\\y', '\\z', '\\_q',
                           '\\4', '\\5', '\\6', '\\7',
                           '\\2', '\\*', '\\-', '\\+', '\\_+',
                           '\\_n', '\\_V', '\\__c', '\\__t']:
-                self.script.append((SCRIPT_TAG, lexeme))
+                self.script.append((SCRIPT_TAG, lexeme, self.column))
             elif lexeme in ['\\0', '\\h']:
-                self.script.append((SCRIPT_TAG, lexeme))
+                self.script.append((SCRIPT_TAG, lexeme, self.column))
                 scope = 0
             elif lexeme in ['\\1', '\\u']:
-                self.script.append((SCRIPT_TAG, lexeme))
+                self.script.append((SCRIPT_TAG, lexeme, self.column))
                 scope = 1
             elif lexeme in ['\\s', '\\b', '\\p']:
                 argument = self.read_sbra_id()
-                self.script.append((SCRIPT_TAG, lexeme, argument))
+                self.script.append((SCRIPT_TAG, lexeme, argument, self.column))
             elif lexeme.startswith('\\s') or \
                  lexeme.startswith('\\b') or \
                  lexeme.startswith('\\p') or \
@@ -216,32 +217,35 @@ class Parser:
                 num = lexeme[2]
                 if lexeme.startswith('\\s') and scope == 1:
                     num = str(int(num) + 10)
-                self.script.append((SCRIPT_TAG, lexeme[:2], num))
+                self.script.append((SCRIPT_TAG, lexeme[:2], num, self.column))
             elif lexeme in ['\\_w']:
                 argument = self.read_sbra_number()
-                self.script.append((SCRIPT_TAG, lexeme, argument))
+                self.script.append((SCRIPT_TAG, lexeme, argument, self.column))
             elif lexeme in ['\\i', '\\j', '\\&', '\\_u', '\\_m']:
                 argument = self.read_sbra_id()
-                self.script.append((SCRIPT_TAG, lexeme, argument))
+                self.script.append((SCRIPT_TAG, lexeme, argument, self.column))
             elif lexeme in ['\\_b', '\\_c', '\\_l', '\\_v', '\\m',
                             '\\3', '\\8', '\\9']:
                 argument = self.read_sbra_text()
-                self.script.append((SCRIPT_TAG, lexeme, argument))
+                self.script.append((SCRIPT_TAG, lexeme, argument, self.column))
             elif lexeme in ['\\n']:
                 if self.tokens and self.tokens[0][0] == TOKEN_OPENED_SBRA:
                     argument = self.read_sbra_text()
-                    self.script.append((SCRIPT_TAG, lexeme, argument))
+                    self.script.append((SCRIPT_TAG, lexeme, argument,
+                                        self.column))
                 else:
-                    self.script.append((SCRIPT_TAG, lexeme))
+                    self.script.append((SCRIPT_TAG, lexeme, self.column))
             elif lexeme in ['\\URL']:
                 buf = [self.read_sbra_text()]
                 while self.tokens and self.tokens[0][0] == TOKEN_OPENED_SBRA:
                     buf.append(self.read_sbra_text())
                     buf.append(self.read_sbra_text())
-                self.script.append((SCRIPT_TAG, lexeme) + tuple(buf))
+                self.script.append((SCRIPT_TAG, lexeme) + tuple(buf) + \
+                                       (self.column, ))
             elif lexeme in ['\\!']:
                 args = self.split_params(self.read_sbra_text())
-                self.script.append((SCRIPT_TAG, lexeme) + tuple(args))
+                self.script.append((SCRIPT_TAG, lexeme) + tuple(args) + \
+                                       (self.column, ))
             elif lexeme in ['\\q']:
                 if self.tokens and self.tokens[0][0] == TOKEN_OPENED_SBRA:
                     args = self.split_params(self.read_sbra_text())
@@ -253,45 +257,50 @@ class Parser:
                                           skip='length')
                     arg1 = args[0]
                     arg2 = args[1][0][1]
-                    self.script.append((SCRIPT_TAG, lexeme, arg1, arg2))
+                    self.script.append((SCRIPT_TAG, lexeme, arg1, arg2,
+                                        self.column))
                 else:
                     arg1 = self.read_number()
                     arg2 = self.read_sbra_id()
                     arg3 = self.read_sbra_text()
-                    self.script.append((SCRIPT_TAG, lexeme, arg1, arg2, arg3))
+                    self.script.append((SCRIPT_TAG, lexeme, arg1, arg2, arg3,
+                                        self.column))
             elif lexeme in ['\\_s']:
                 if self.tokens and self.tokens[0][0] == TOKEN_OPENED_SBRA:
                     args = [arg[0][1] for arg in \
                             self.split_params(self.read_sbra_text())]
-                    self.script.append((SCRIPT_TAG, lexeme) + tuple(args))
+                    self.script.append((SCRIPT_TAG, lexeme) + tuple(args) + \
+                                           (self.column, ))
                 else:
-                    self.script.append((SCRIPT_TAG, lexeme))
+                    self.script.append((SCRIPT_TAG, lexeme, self.column))
             elif lexeme in ['\\_a']:
                 if anchor is None:
                     anchor = self.perror(r'syntax error (unbalanced \_a tag)',
                                          skip='rest')
                     self.script.append(
-                        (SCRIPT_TAG, lexeme, self.read_sbra_id()))
+                        (SCRIPT_TAG, lexeme, self.read_sbra_id(), self.column))
                 else:
                     anchor = None
-                    self.script.append((SCRIPT_TAG, lexeme))
+                    self.script.append((SCRIPT_TAG, lexeme, self.column))
             elif lexeme in ['\\f']:
                 args = [arg[0][1] for arg in \
                         self.split_params(self.read_sbra_text())]
-                self.script.append((SCRIPT_TAG, lexeme) + tuple(args))
+                self.script.append((SCRIPT_TAG, lexeme) + tuple(args) + \
+                                       (self.column, ))
             else:
                 raise self.perror('unknown tag ({0})'.format(lexeme), skip='length')
         if anchor:
-            if self.script[-1] == (SCRIPT_TAG, r'\e'):
-                self.script.insert(len(self.script) - 1, (SCRIPT_TAG, r'\_a'))
+            if self.script[-1][0:2] == (SCRIPT_TAG, r'\e'):
+                self.script.insert(len(self.script) - 1,
+                                   (SCRIPT_TAG, r'\_a', self.script[-1][2]))
             else:
-                self.script.append((SCRIPT_TAG, r'\_a'))
+                self.script.append((SCRIPT_TAG, r'\_a', self.column))
             anchor.script=self.script
             raise anchor
         if string_chunks:
             text.append((TEXT_STRING, ''.join(string_chunks)))
         if text:
-            self.script.append((SCRIPT_TEXT, tuple(text)))
+            self.script.append((SCRIPT_TEXT, tuple(text), self.column))
         return self.script
 
     def read_number(self):
@@ -476,7 +485,7 @@ def test_parser(error='strict'):
 def print_script_tree(tree):
     for node in tree:
         if node[0] == SCRIPT_TAG:
-            name, args = node[1], node[2:]
+            name, args = node[1], node[2:-1]
             print('TAG', name)
             for n in range(len(args)):
                 if isinstance(args[n], str):
