@@ -299,44 +299,50 @@ class Surface:
 
     def get_menu_pixmap(self):
         top_dir = self.prefix
-        name = self.desc.get('menu.background.bitmap.filename',
-                             'menu_background.png')
-        name = name.replace('\\', '/')
-        path_background = os.path.join(top_dir, os.fsencode(name))
-        name = self.desc.get('menu.sidebar.bitmap.filename',
-                             'menu_sidebar.png')
-        name = name.replace('\\', '/')
-        path_sidebar = os.path.join(top_dir, os.fsencode(name))
-        name = self.desc.get('menu.foreground.bitmap.filename',
-                             'menu_foreground.png')
-        name = name.replace('\\', '/')
-        path_foreground = os.path.join(top_dir, os.fsencode(name))
-        align_background = self.desc.get('menu.background.alignment',
-                                         'lefttop')
-        if align_background not in ['lefttop', 'righttop', 'centertop']:
-            align_background = 'lefttop'
-        align_background = align_background[:-3].encode('ascii') # XXX
-        align_sidebar = self.desc.get('menu.sidebar.alignment',
-                                      'top')
-        if align_sidebar not in ['top', 'bottom']:
-            align_sidebar = 'top'
-        align_sidebar = align_sidebar.encode('ascii') # XXX
-        align_foreground = self.desc.get('menu.foreground.alignment',
-                                         'lefttop')
-        if align_foreground not in ['lefttop', 'righttop', 'centertop']:
-            align_foreground = 'lefttop'
-        align_foreground = align_foreground[:-3].encode('ascii') # XXX
+        name = self.desc.get('menu.background.bitmap.filename')
+        if name:
+            name = name.replace('\\', '/')
+            path_background = os.path.join(top_dir, os.fsencode(name))
+        else:
+            path_background = None
+        name = self.desc.get('menu.sidebar.bitmap.filename')
+        if name:
+            name = name.replace('\\', '/')
+            path_sidebar = os.path.join(top_dir, os.fsencode(name))
+        else:
+            path_sidebar = None
+        name = self.desc.get('menu.foreground.bitmap.filename')
+        if name:
+            name = name.replace('\\', '/')
+            path_foreground = os.path.join(top_dir, os.fsencode(name))
+        else:
+            path_foreground = None
+        align_background = self.desc.get('menu.background.alignment')
+        align_sidebar = self.desc.get('menu.sidebar.alignment')
+        align_foreground = self.desc.get('menu.foreground.alignment')
         return path_background, path_sidebar, path_foreground, \
             align_background, align_sidebar, align_foreground
 
     def get_menu_fontcolor(self):
-        fontcolor_r = self.desc.get_with_type('menu.background.font.color.r', int, 0)
-        fontcolor_g = self.desc.get_with_type('menu.background.font.color.g', int, 0)
-        fontcolor_b = self.desc.get_with_type('menu.background.font.color.b', int, 0)
+        fontcolor_r = self.desc.get_with_type(
+            'menu.background.font.color.r', int, 0)
+        fontcolor_g = self.desc.get_with_type(
+            'menu.background.font.color.g', int, 0)
+        fontcolor_b = self.desc.get_with_type(
+            'menu.background.font.color.b', int, 0)
+        fontcolor_r = max(0, min(255, fontcolor_r))
+        fontcolor_g = max(0, min(255, fontcolor_g))
+        fontcolor_b = max(0, min(255, fontcolor_b))
         background = (fontcolor_r, fontcolor_g, fontcolor_b)
-        fontcolor_r = self.desc.get_with_type('menu.foreground.font.color.r', int, 0)
-        fontcolor_g = self.desc.get_with_type('menu.foreground.font.color.g', int, 0)
-        fontcolor_b = self.desc.get_with_type('menu.foreground.font.color.b', int, 0)
+        fontcolor_r = self.desc.get_with_type(
+            'menu.foreground.font.color.r', int, 0)
+        fontcolor_g = self.desc.get_with_type(
+            'menu.foreground.font.color.g', int, 0)
+        fontcolor_b = self.desc.get_with_type(
+            'menu.foreground.font.color.b', int, 0)
+        fontcolor_r = max(0, min(255, fontcolor_r))
+        fontcolor_g = max(0, min(255, fontcolor_g))
+        fontcolor_b = max(0, min(255, fontcolor_b))
         foreground = (fontcolor_r, fontcolor_g, fontcolor_b)
         return background, foreground
 
