@@ -56,7 +56,8 @@ class NetworkUpdate:
     def start(self, homeurl, ghostdir, timeout=60):
         url = urllib.parse.urlparse(homeurl)
         if not (url[0] == 'http' and url[3] == url[4] == url[5] == ''):
-            self.enqueue_event('OnUpdateFailure', 'bad home URL')
+            self.enqueue_event('OnUpdateFailure', 'bad home URL', '', '',
+                               'ghost') # XXX
             self.state = None
             return
         try:
@@ -73,7 +74,9 @@ class NetworkUpdate:
     def interrupt(self):
         self.event_queue = []
         self.request_parent(
-            'NOTIFY', 'enqueue_event', 'OnUpdateFailure', 'artificial')
+            'NOTIFY', 'enqueue_event',
+            'OnUpdateFailure', 'artificial', '', '',
+            'ghost') # XXX
         self.state = None
         self.stop(revert=1)
 
@@ -144,7 +147,10 @@ class NetworkUpdate:
         return 1
 
     def start_updates(self):
-        self.enqueue_event('OnUpdateBegin')
+        self.enqueue_event(
+            'OnUpdateBegin', self.request_parent('GET', 'get_name', ''),
+            os.fsdecode(self.path), '',
+            'ghost') # XXX
         self.download(os.path.join(self.path, b'updates2.dau'))
 
     def download(self, locator, event=0):
@@ -153,7 +159,8 @@ class NetworkUpdate:
         if event:
             self.enqueue_event('OnUpdate.OnDownloadBegin',
                                os.path.basename(locator),
-                               self.file_number, self.num_files)
+                               self.file_number, self.num_files,
+                               'ghost') # XXX
         self.state += 1
         self.reset_timeout()
 
@@ -161,12 +168,14 @@ class NetworkUpdate:
         try:
             self.http.connect()
         except:
-            self.enqueue_event('OnUpdateFailure', 'connection failed')
+            self.enqueue_event('OnUpdateFailure', 'connection failed', '', '',
+                               'ghost') # XXX
             self.state = None
             self.stop(revert=1)
             return
         if self.check_timeout():
-            self.enqueue_event('OnUpdateFailure', 'timeout')
+            self.enqueue_event('OnUpdateFailure', 'timeout', '', '',
+                               'ghost') # XXX
             self.state = None
             self.stop(revert=1)
             return
@@ -178,12 +187,14 @@ class NetworkUpdate:
         try:
             self.response = self.http.getresponse()
         except:
-            self.enqueue_event('OnUpdateFailure', 'no HTTP response')
+            self.enqueue_event('OnUpdateFailure', 'no HTTP response', '', '',
+                               'ghost') # XXX
             self.state = None
             self.stop(revert=1)
             return
         if self.check_timeout():
-            self.enqueue_event('OnUpdateFailure', 'timeout')
+            self.enqueue_event('OnUpdateFailure', 'timeout', '', '',
+                               'ghost') # XXX
             self.state = None
             self.stop(revert=1)
             return
@@ -194,7 +205,9 @@ class NetworkUpdate:
         elif code == 302 and self.redirect():
             return
         elif self.state == 2: # updates2.dau
-            self.enqueue_event('OnUpdateFailure', str(code))
+            self.enqueue_event(
+                'OnUpdateFailure', str(code), 'updates2.dau', '',
+                'ghost') # XXX
             self.state = None
             return
         else:
@@ -238,14 +251,17 @@ class NetworkUpdate:
         data = self.response.read()
         if not data:
             if self.check_timeout():
-                self.enqueue_event('OnUpdateFailure', 'timeout')
+                self.enqueue_event('OnUpdateFailure', 'timeout', '', '',
+                                   'ghost') # XXX
                 self.state = None
                 self.stop(revert=1)
                 return
             elif data is None:
                 return
         elif self.response.status != http.client.OK:
-            self.enqueue_event('OnUpdateFailure', 'data retrieval failed')
+            self.enqueue_event(
+                'OnUpdateFailure', 'data retrieval failed', '', '',
+                'ghost') # XXX
             self.state = None
             self.stop(revert=1)
             return
@@ -276,8 +292,11 @@ class NetworkUpdate:
         if schedule is not None:
             self.num_files = len(schedule) - 1
             self.file_number = 0
+            update_list = ','.join([os.fsdecode(x) for x, y in schedule])
             if self.num_files >= 0:
-                self.enqueue_event('OnUpdateReady', self.num_files)
+                self.enqueue_event(
+                    'OnUpdateReady', self.num_files, update_list, '',
+                    'ghost') # XXX
             self.state += 1
         return schedule
 
@@ -288,7 +307,9 @@ class NetworkUpdate:
             try:
                 filename, checksum, newline = line.split(b'\001', 2)
             except ValueError:
-                self.enqueue_event('OnUpdateFailure', 'broken updates2.dau')
+                self.enqueue_event('OnUpdateFailure', 'broken updates2.dau',
+                                   'updates2.dau', '',
+                                   'ghost') # XXX
                 self.state = None
                 return None
             if not filename:
@@ -311,6 +332,9 @@ class NetworkUpdate:
         return schedule
 
     def update_file(self, filename, checksum):
+        self.enqueue_event('OnUpdate.OnMD5CompareBegin',
+                           os.fsdecode(filename), '', '',
+                           'ghost') # XXX
         data = b''.join(self.buffer)
         m = hashlib.md5()
         m.update(data)
@@ -331,7 +355,10 @@ class NetworkUpdate:
                     os.makedirs(subdir)
                 except OSError:
                     self.enqueue_event(
-                        'OnUpdateFailure', ''.join(("can't mkdir ", subdir)))
+                        'OnUpdateFailure',
+                        ''.join(("can't mkdir ", os.fsdeocde(subdir))),
+                        os.fsdecode(path), '',
+                        'ghost') # XXX
                     self.state = None
                     self.stop(revert=1)
                     return
@@ -349,14 +376,19 @@ class NetworkUpdate:
                     except IOError:
                         self.enqueue_event(
                             'OnUpdateFailure',
-                            ''.join(("can't write ", os.path.basename(path))))
+                            ''.join(("can't write ",
+                                     os.fsdecode(os.path.basename(path)))),
+                            os.fsdecode(path), '',
+                            'ghost') # XXX
                         self.state = None
                         self.stop(revert=1)
                         return
             except IOError:
                 self.enqueue_event(
                     'OnUpdateFailure',
-                    ''.join(("can't open ", os.path.basename(path))))
+                    ''.join(("can't open ", os.path.basename(path))),
+                    os.fsdecode(path), '',
+                    'ghost') # XXX
                 self.state = None
                 self.stop(revert=1)
                 return
@@ -364,7 +396,8 @@ class NetworkUpdate:
             event = 'OnUpdate.OnMD5CompareComplete'
         else:
             event = 'OnUpdate.OnMD5CompareFailure'
-            self.enqueue_event(event, filename, checksum, digest)
+            self.enqueue_event(event, os.fsdecode(filename), checksum, digest,
+                               'ghost') # XXX
             self.state = None
             self.stop(revert=1)
             return
@@ -385,9 +418,11 @@ class NetworkUpdate:
                         logging.error(e)
         update_list = ','.join([os.fsdecode(x) for x in self.updated_files])
         if not update_list:
-            self.enqueue_event('OnUpdateComplete', 'none')
+            self.enqueue_event('OnUpdateComplete', 'none', '', '',
+                               'ghost') # XXX
         else:
-            self.enqueue_event('OnUpdateComplete', 'changed', update_list)
+            self.enqueue_event('OnUpdateComplete', 'changed', update_list, '',
+                               'ghost') # XXX
         self.state = None
         self.stop()
 
